@@ -1,4 +1,4 @@
-/* $OpenBSD: ec2_smpl.c,v 1.15 2017/01/29 17:49:23 beck Exp $ */
+/* $OpenBSD: ec2_smpl.c,v 1.20.2.1 2018/11/17 18:55:41 tb Exp $ */
 /* ====================================================================
  * Copyright 2002 Sun Microsystems, Inc. ALL RIGHTS RESERVED.
  *
@@ -107,18 +107,15 @@ EC_GF2m_simple_method(void)
 		.point_cmp = ec_GF2m_simple_cmp,
 		.make_affine = ec_GF2m_simple_make_affine,
 		.points_make_affine = ec_GF2m_simple_points_make_affine,
-
-		/*
-		 * the following three method functions are defined in
-		 * ec2_mult.c
-		 */
-		.mul = ec_GF2m_simple_mul,
+		.mul_generator_ct = ec_GFp_simple_mul_generator_ct,
+		.mul_single_ct = ec_GFp_simple_mul_single_ct,
+		.mul_double_nonct = ec_GFp_simple_mul_double_nonct,
 		.precompute_mult = ec_GF2m_precompute_mult,
 		.have_precompute_mult = ec_GF2m_have_precompute_mult,
-
 		.field_mul = ec_GF2m_simple_field_mul,
 		.field_sqr = ec_GF2m_simple_field_sqr,
 		.field_div = ec_GF2m_simple_field_div,
+		.blind_coordinates = NULL,
 	};
 
 	return &ret;
@@ -232,7 +229,7 @@ ec_GF2m_simple_group_set_curve(EC_GROUP * group,
 		group->b.d[i] = 0;
 
 	ret = 1;
-err:
+ err:
 	return ret;
 }
 
@@ -260,7 +257,7 @@ ec_GF2m_simple_group_get_curve(const EC_GROUP *group,
 	}
 	ret = 1;
 
-err:
+ err:
 	return ret;
 }
 
@@ -306,7 +303,7 @@ ec_GF2m_simple_group_check_discriminant(const EC_GROUP * group, BN_CTX * ctx)
 
 	ret = 1;
 
-err:
+ err:
 	if (ctx != NULL)
 		BN_CTX_end(ctx);
 	BN_CTX_free(new_ctx);
@@ -398,7 +395,7 @@ ec_GF2m_simple_point_set_affine_coordinates(const EC_GROUP * group, EC_POINT * p
 	point->Z_is_one = 1;
 	ret = 1;
 
-err:
+ err:
 	return ret;
 }
 
@@ -432,7 +429,7 @@ ec_GF2m_simple_point_get_affine_coordinates(const EC_GROUP *group,
 	}
 	ret = 1;
 
-err:
+ err:
 	return ret;
 }
 
@@ -549,7 +546,7 @@ ec_GF2m_simple_add(const EC_GROUP *group, EC_POINT *r, const EC_POINT *a,
 
 	ret = 1;
 
-err:
+ err:
 	BN_CTX_end(ctx);
 	BN_CTX_free(new_ctx);
 	return ret;
@@ -641,7 +638,7 @@ ec_GF2m_simple_is_on_curve(const EC_GROUP *group, const EC_POINT *point, BN_CTX
 	if (!BN_GF2m_add(lh, lh, y2))
 		goto err;
 	ret = BN_is_zero(lh);
-err:
+ err:
 	if (ctx)
 		BN_CTX_end(ctx);
 	BN_CTX_free(new_ctx);
@@ -693,7 +690,7 @@ ec_GF2m_simple_cmp(const EC_GROUP *group, const EC_POINT *a,
 		goto err;
 	ret = ((BN_cmp(aX, bX) == 0) && BN_cmp(aY, bY) == 0) ? 0 : 1;
 
-err:
+ err:
 	if (ctx)
 		BN_CTX_end(ctx);
 	BN_CTX_free(new_ctx);
@@ -734,7 +731,7 @@ ec_GF2m_simple_make_affine(const EC_GROUP * group, EC_POINT * point, BN_CTX * ct
 
 	ret = 1;
 
-err:
+ err:
 	if (ctx)
 		BN_CTX_end(ctx);
 	BN_CTX_free(new_ctx);
