@@ -13,6 +13,9 @@
 #include_next <time.h>
 #endif
 
+#ifndef LIBCRYPTOCOMPAT_TIME_H
+#define LIBCRYPTOCOMPAT_TIME_H
+
 #ifdef _WIN32
 struct tm *__gmtime_r(const time_t * t, struct tm * tm);
 #define gmtime_r(tp, tm) __gmtime_r(tp, tm)
@@ -22,6 +25,20 @@ struct tm *__gmtime_r(const time_t * t, struct tm * tm);
 time_t timegm(struct tm *tm);
 #endif
 
+#ifndef CLOCK_MONOTONIC
+#define CLOCK_MONOTONIC CLOCK_REALTIME
+#endif
+
+#ifndef CLOCK_REALTIME
+#define CLOCK_REALTIME 0
+#endif
+
+#ifndef _WIN32
+#ifndef HAVE_CLOCK_GETTIME
+typedef int clockid_t;
+int clock_gettime(clockid_t clock_id, struct timespec *tp);
+#endif
+
 #ifndef timespecsub
 #define timespecsub(tsp, usp, vsp)                                      \
         do {                                                            \
@@ -33,3 +50,6 @@ time_t timegm(struct tm *tm);
                 }                                                       \
         } while (0)
 #endif
+#endif
+
+#endif
